@@ -33,6 +33,8 @@ public:
     void draw(QPainter *painter);
     void updateValue(int value);
 
+    void setDbUnit(bool b);
+
 signals:
 
 protected:
@@ -40,6 +42,7 @@ protected:
 
 private:
     int currentValue;
+    bool dbUnit;
 
 };
 
